tools:::Rd_package_description("forsearch")
William R. Fairweather, Flower Valley Consulting, Inc., Silver Spring MD USA tools:::Rd_package_author("forsearch")
Maintainer: tools:::Rd_package_maintainer("forsearch") William R. Fairweather <wrf343 AT flowervalleyconsulting DOT com>
The DESCRIPTION file: tools:::Rd_package_DESCRIPTION("forsearch") tools:::Rd_package_indices("forsearch") Ensure that data frame has a leading column of observation numbers. Run forsearch_foo to create a file of diagnostic statistics to be used as input to such plotting functions as plotdiag.residuals, plotdiag.params.fixed, plotdiag.params.random, plotdiag.s2, plotdiag,leverage, and plotdiag.Cook. The file of diagnostic statistics can be voluminous, and the utility function showme displays the output more succinctly. Plotting of statistics for fixed and for random coefficients is limited by graphical restraints in some cases. The function identifyCoeffs provides a set of indexing codes so that plotdiag.params.random can display diagnostics for selected fixed or random model parameters. The function identifyFixedCoeffs does the same for lm models.
Atkinson, A and M Riani. Robust Diagnostic Regression Analysis, Springer, New York, 2000. Pinheiro, JC and DM Bates. Mixed-Effects Models in S and S-Plus, Springer, New York, 2000.