Plot output from forsearch_lm or forsearch_lme to show change in residuals or squared residuals as the number of observations in the forward search procedure increases. Save plot in folder containing working directory.
plotdiag.residuals(forn, squared = FALSE, hilos = c(1, 0), maintitle, subtitle,
caption, wmf, Cairo=TRUE,printgraph=TRUE,
legend = "Dummy legend name", verbose = TRUE)Process and plot changes in residuals or squared residuals from forsearch_lm or forsearch_lme
Name of forward search output file
TRUE causes residuals to be squared before plotting
Number of observations having high and number having low values of residuals to identify. No low values are identified for squared residual plot.
Main title of plot
Subtitle of plot
Caption of plot
File name of stored plot; omit ".wmf"
TRUE causes use of Cairo graphics
TRUE causes graph to print to file and closes device
Legend title
If TRUE, indicates beginning and end of function
William R. Fairweather
Atkinson, A and M Riani. Robust Diagnostic Regression Analysis, Springer, New York, 2000.