Learn R Programming

forsearch (version 6.4.0)

search.history: Create Tabular History Of Forward Search

Description

The forward search functions output a list of vectors, each of which indicates which observations are in the model at each stage of the search. This function processes that list to create a more easily understood matrix of the observation numbers that are newly entered into the model and any that were temporarily removed from the model over the course of the search.

Usage

search.history(list1, verbose = TRUE)

Value

Printout of matrix showing evolution of observations to enter or leave the model during the course of the forward search

Arguments

list1

Name of a forsearch_xxx output file

verbose

If TRUE, indicates beginning and end of function

Author

William R. Fairweather

Examples

Run this code
info3 <- system.file("extdata", "crossdata.for1.R", package="forsearch");
info3 <- source(info3);
info3 <- info3[[1]];
search.history(list1=info3, verbose=TRUE)

Run the code above in your browser using DataLab