Learn R Programming

forsearch (version 6.4.0)

showme: Display Abbreviated Output of FORSEARCH_xxx Function

Description

Output of forsearch_xxx function can be voluminous. This function displays the output in an abbreviated format. Primarily for programmer use.

Usage

showme(x, verbose = TRUE)

Value

Abbreviated printout of output of forsearch_lm function

Arguments

x

Name of forsearch_xxx output file

verbose

If TRUE, indicates the beginning and end of function run

Author

William R. Fairweather