search.history: Create Tabular History Of Forward Search
Description
The forward search functions output a list of vectors, each of which indicates which observations
are in the model at each stage of the search. This function processes that list to create a more easily
understood matrix of the observation numbers that are newly entered into the model and any that
were temporarily removed from the model over the course of the search.
Usage
search.history(list1, verbose = TRUE)
Value
Printout of matrix showing evolution of observations to enter or leave
the model during the course of the forward search